==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/HelmMappingRuleProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Helm mapping rule profile
 * @property helmPackageVersion Helm package version.
 * @property options The helm deployment options
 * @property releaseName Helm release name.
 * @property releaseNamespace Helm release namespace.
 * @property values Helm release values.
 */
public data class HelmMappingRuleProfileArgs(
    public val helmPackageVersion: Output<String>? = null,
    public val options: Output<HelmMappingRuleProfileOptionsArgs>? = null,
    public val releaseName: Output<String>? = null,
    public val releaseNamespace: Output<String>? = null,
    public val values: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder()
            .helmPackageVersion(helmPackageVersion?.applyValue({ args0 -> args0 }))
            .options(options?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .releaseName(releaseName?.applyValue({ args0 -> args0 }))
            .releaseNamespace(releaseNamespace?.applyValue({ args0 -> args0 }))
            .values(values?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HelmMappingRuleProfileArgs].
 */
@PulumiTagMarker
public class HelmMappingRuleProfileArgsBuilder internal constructor() {
    private var helmPackageVersion: Output<String>? = null

    private var options: Output<HelmMappingRuleProfileOptionsArgs>? = null

    private var releaseName: Output<String>? = null

    private var releaseNamespace: Output<String>? = null

    private var values: Output<String>? = null

    /**
     * @param value Helm package version.
     */
    @JvmName("snjvtmkuhucycskh")
    public suspend fun helmPackageVersion(`value`: Output<String>) {
        this.helmPackageVersion = value
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("aweifahsosagjkcv")
    public suspend fun options(`value`: Output<HelmMappingRuleProfileOptionsArgs>) {
        this.options = value
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("rhmjmmukqehellpn")
    public suspend fun releaseName(`value`: Output<String>) {
        this.releaseName = value
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("eaipntgbiggovcis")
    public suspend fun releaseNamespace(`value`: Output<String>) {
        this.releaseNamespace = value
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("rtpwykwottlbivrf")
    public suspend fun values(`value`: Output<String>) {
        this.values = value
    }

    /**
     * @param value Helm package version.
     */
    @JvmName("wwrpdryxnalwxakq")
    public suspend fun helmPackageVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.helmPackageVersion = mapped
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("bwycbybeiyvscvgw")
    public suspend fun options(`value`: HelmMappingRuleProfileOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.options = mapped
    }

    /**
     * @param argument The helm deployment options
     */
    @JvmName("jublmfpwqvulxklq")
    public suspend
    fun options(argument: suspend HelmMappingRuleProfileOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = HelmMappingRuleProfileOptionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.options = mapped
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("pxkscgsaqxlkdyeg")
    public suspend fun releaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseName = mapped
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("qsonheluhsncvkxx")
    public suspend fun releaseNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseNamespace = mapped
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("vvxdmxpyjxbhhmyp")
    public suspend fun values(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): HelmMappingRuleProfileArgs = HelmMappingRuleProfileArgs(
        helmPackageVersion = helmPackageVersion,
        options = options,
        releaseName = releaseName,
        releaseNamespace = releaseNamespace,
        values = values,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/HelmMappingRuleProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Helm mapping rule profile
 * @property helmPackageVersion Helm package version.
 * @property options The helm deployment options
 * @property releaseName Helm release name.
 * @property releaseNamespace Helm release namespace.
 * @property values Helm release values.
 */
public data class HelmMappingRuleProfileArgs(
    public val helmPackageVersion: Output<String>? = null,
    public val options: Output<HelmMappingRuleProfileOptionsArgs>? = null,
    public val releaseName: Output<String>? = null,
    public val releaseNamespace: Output<String>? = null,
    public val values: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder()
            .helmPackageVersion(helmPackageVersion?.applyValue({ args0 -> args0 }))
            .options(options?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .releaseName(releaseName?.applyValue({ args0 -> args0 }))
            .releaseNamespace(releaseNamespace?.applyValue({ args0 -> args0 }))
            .values(values?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HelmMappingRuleProfileArgs].
 */
@PulumiTagMarker
public class HelmMappingRuleProfileArgsBuilder internal constructor() {
    private var helmPackageVersion: Output<String>? = null

    private var options: Output<HelmMappingRuleProfileOptionsArgs>? = null

    private var releaseName: Output<String>? = null

    private var releaseNamespace: Output<String>? = null

    private var values: Output<String>? = null

    /**
     * @param value Helm package version.
     */
    @JvmName("tfinrchbveomdwxc")
    public suspend fun helmPackageVersion(`value`: Output<String>) {
        this.helmPackageVersion = value
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("gegrttbpydmbcfwb")
    public suspend fun options(`value`: Output<HelmMappingRuleProfileOptionsArgs>) {
        this.options = value
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("jhhspnfltqlicxln")
    public suspend fun releaseName(`value`: Output<String>) {
        this.releaseName = value
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("eviodkvydxtjrwfl")
    public suspend fun releaseNamespace(`value`: Output<String>) {
        this.releaseNamespace = value
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("lruxapqijdyrvswv")
    public suspend fun values(`value`: Output<String>) {
        this.values = value
    }

    /**
     * @param value Helm package version.
     */
    @JvmName("shnijmawmkvfmbel")
    public suspend fun helmPackageVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.helmPackageVersion = mapped
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("byhylxwtpxhyqdep")
    public suspend fun options(`value`: HelmMappingRuleProfileOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.options = mapped
    }

    /**
     * @param argument The helm deployment options
     */
    @JvmName("yjwoesjctufgtiqw")
    public suspend
    fun options(argument: suspend HelmMappingRuleProfileOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = HelmMappingRuleProfileOptionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.options = mapped
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("ohmgoabkutppeied")
    public suspend fun releaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseName = mapped
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("dmabtstrbedeqska")
    public suspend fun releaseNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseNamespace = mapped
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("ihqrrofmxkbiukdv")
    public suspend fun values(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): HelmMappingRuleProfileArgs = HelmMappingRuleProfileArgs(
        helmPackageVersion = helmPackageVersion,
        options = options,
        releaseName = releaseName,
        releaseNamespace = releaseNamespace,
        values = values,
    )
}
